@@ -13,7 +13,7 @@ def get_files(**kwargs):
             ),
         ),
         File(
-            Path(kwargs['package_name'], '__init__.py'),
+            Path('src', kwargs['package_name'], '__init__.py'),
             f"""\
 # SPDX-FileCopyrightText: {kwargs['year']}-present {kwargs['author']} <{kwargs['email']}>
 #
@@ -21,12 +21,12 @@ def get_files(**kwargs):
 """,
         ),
         File(
-            Path(kwargs['package_name'], '__about__.py'),
+            Path('src', kwargs['package_name'], '__about__.py'),
             f"""\
 # SPDX-FileCopyrightText: {kwargs['year']}-present {kwargs['author']} <{kwargs['email']}>
 #
 # SPDX-License-Identifier: MIT
-__version__ = '0.0.1'
+__version__ = "0.0.1"
 """,
         ),
         File(
@@ -64,9 +64,10 @@ build-backend = "hatchling.build"
 
 [project]
 name = "{kwargs['project_name_normalized']}"
+dynamic = ["version"]
 description = ''
 readme = "README.md"
-requires-python = ">=3.7"
+requires-python = ">=3.8"
 license = "MIT"
 keywords = []
 authors = [
@@ -75,16 +76,15 @@ authors = [
 classifiers = [
   "Development Status :: 4 - Beta",
   "Programming Language :: Python",
-  "Programming Language :: Python :: 3.7",
   "Programming Language :: Python :: 3.8",
   "Programming Language :: Python :: 3.9",
   "Programming Language :: Python :: 3.10",
   "Programming Language :: Python :: 3.11",
+  "Programming Language :: Python :: 3.12",
   "Programming Language :: Python :: Implementation :: CPython",
   "Programming Language :: Python :: Implementation :: PyPy",
 ]
 dependencies = []
-dynamic = ["version"]
 
 [project.urls]
 Documentation = "https://github.com/unknown/{kwargs['project_name_normalized']}#readme"
@@ -92,7 +92,7 @@ Issues = "https://github.com/unknown/{kwargs['project_name_normalized']}/issues"
 Source = "https://github.com/unknown/{kwargs['project_name_normalized']}"
 
 [tool.hatch.version]
-path = "{kwargs['package_name']}/__about__.py"
+path = "src/{kwargs['package_name']}/__about__.py"
 """,
         ),
-    ]  # noqa: E501
+    ]
